@@ -112,7 +112,7 @@ public:
      * 
      * Presage does not take ownership of the callback object.
      */
-    Presage(PresageCallback* callback) throw (PresageException);
+    Presage(PresageCallback* callback);
 
 
     /** Creates and initializes presage with supplied configuration.
@@ -122,7 +122,7 @@ public:
      *
      * Presage does not take ownership of the callback object.
      */
-    Presage(PresageCallback* callback, const std::string config) throw (PresageException);
+    Presage(PresageCallback* callback, const std::string config);
 
 
     /** Destroys presage.
@@ -138,7 +138,7 @@ public:
      * context.
      *
      */
-    std::vector<std::string> predict() throw (PresageException);
+    std::vector<std::string> predict();
 
     /** \brief Obtain a prediction that matches the supplied token
      *         filter.
@@ -153,7 +153,7 @@ public:
      * of the filter tokens.
      *
      */
-    std::multimap<double, std::string> predict(std::vector<std::string> filter) throw (PresageException);
+    std::multimap<double, std::string> predict(std::vector<std::string> filter);
 
     /** \brief Learn from text offline.
      *
@@ -167,7 +167,7 @@ public:
      * \param text a text string to learn from.
      *
      */
-    void learn(const std::string text) const throw (PresageException);
+    void learn(const std::string text);
 
     /** \brief Callback getter/setter.
      *
@@ -176,7 +176,7 @@ public:
      *
      * \return pointer to previously used callback
      */
-    PresageCallback* callback(PresageCallback* callback) throw (PresageException);
+    PresageCallback* callback(PresageCallback* callback);
 
     /** \brief Request presage to return the completion string for the given predicted token.
      *
@@ -190,26 +190,26 @@ public:
      *
      * \return completion string
      */
-    std::string completion(std::string str) throw (PresageException);
+    std::string completion(std::string str);
 
     /** \brief Returns the text entered so far.
      *
      * \return context, text entered so far.
      */
-    std::string context() const throw (PresageException);
+    std::string context();
 
     /** \brief Returns true if a context change occured.
      *
      * \return true if a context change occured after the last update
      * or predict calls, or false otherwise.
      */
-    bool context_change() const throw (PresageException);
+    bool context_change();
 
     /** \brief Returns the current prefix.
      *
      * \return prefix
      */
-    std::string prefix() const throw (PresageException);
+    std::string prefix();
 
     /** \brief Gets the value of specified configuration variable.
      *
@@ -218,7 +218,7 @@ public:
      *
      * \return value assigned to configuration variable.
      */
-    std::string config(const std::string variable) const throw (PresageException);
+    std::string config(const std::string variable);
 
     /** \brief Sets the value of specified configuration variable.
      *
@@ -227,7 +227,7 @@ public:
      * from the configuration file in use.
      *
      */
-    void config(const std::string variable, const std::string value) const throw (PresageException);
+    void config(const std::string variable, const std::string value);
 
     /** \brief Save current configuration to file.
      *
@@ -236,7 +236,7 @@ public:
      * active XML profile.
      *
      */
-    void save_config() const throw (PresageException);
+    void save_config();
 
     /*
      * Presage public API ends here
